package com.ppshein.sevendaynews;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteException;
import android.database.sqlite.SQLiteOpenHelper;
import android.util.Log;

public class DatabaseUtil{

	private static final String TAG = "DatabaseUtil";
	private static final String DATABASE_NAME = "planetnews.db";
	private static final int DATABASE_VERSION = 3;
	private static final String DATABASE_TABLE = "tb_news";
	public static final String newsid = "newsid";
	public static final String newstitle = "newstitle";
	public static final String newsimage = "newsimage";
	public static final String newslargeimage = "newslargeimage";
	public static final String newsstory = "newsstory";	
	public static final String newscategory = "newscategory";	
	
	private static final String CREATE_PLANET_TABLE = "create table tb_news(newsid integer primary key, newstitle text, newsimage text, newslargeimage text, newsstory text, newscategory text);";
	
	private final Context myContext;

	private DatabaseHelper mDbHelper;
	private SQLiteDatabase mDb;

	private static class DatabaseHelper extends SQLiteOpenHelper {		

		DatabaseHelper(Context context) {
			super(context, DATABASE_NAME, null, DATABASE_VERSION);			
		}

		@Override
		public void onCreate(SQLiteDatabase db) {
		     try {
		    	 db.execSQL(CREATE_PLANET_TABLE);
             } catch (SQLiteException  e) {
          }							
		}		
		
		@Override
		public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
			Log.w(TAG, "Upgrading database from version " + oldVersion + " to "
					+ newVersion);
		}
	}		  
    
	public DatabaseUtil(Context ctx) {
		this.myContext = ctx;
	}	
	
	public boolean deleteOldData() {
		Cursor mCursor =
				mDb.rawQuery("delete from tb_news where newsid = (SELECT newsid from tb_news order by newsid asc limit 20)", null);
		if (mCursor != null) {
			mCursor.moveToFirst();
		}		
		return true;
	}	
	
	public DatabaseUtil open() throws SQLException {
		mDbHelper = new DatabaseHelper(myContext);
		mDb = mDbHelper.getWritableDatabase();
		return this;
	}

	public Cursor getTotalRecord() throws SQLException {
		Cursor mCursor =
				mDb.rawQuery("SELECT Count(newsid) AS totalcount from tb_news", null);
			if (mCursor != null) {
				mCursor.moveToFirst();
			}
			return mCursor;		
	}	
	
	public long insertRecord (String id, String title, String smallimage, String largeimage, String story, String category) {
		ContentValues initialValues = new ContentValues();
		initialValues.put(newsid, Integer.parseInt(id.toString()));
		initialValues.put(newstitle, title);
		initialValues.put(newsimage, smallimage);
		initialValues.put(newslargeimage, largeimage);
		initialValues.put(newsstory, story);
		initialValues.put(newscategory, category);
		return mDb.insert(DATABASE_TABLE, null, initialValues);
	}
	
	
	public void close() {
		mDbHelper.close();
	}
	
	public Cursor fetchAllData(String categortName) {
		if (categortName.equals("NULL")) {
			Cursor mCursor =
				mDb.rawQuery("SELECT newsid, newstitle, newsimage, newscategory from tb_news order by newsid desc", null);
			if (mCursor != null) {
				mCursor.moveToFirst();
			}
			return mCursor;
		} else {
			Cursor mCursor =
					mDb.rawQuery("SELECT newsid, newstitle, newsimage, newscategory from tb_news where newscategory = '" + categortName + "' order by newsid desc", null);
			if (mCursor != null) {
				mCursor.moveToFirst();
			}
			return mCursor;
		}
	}	

	public Cursor getlastRecord() throws SQLException {
		Cursor mCursor =
				mDb.rawQuery("SELECT newsid from tb_news order by newsid desc limit 1", null);
			if (mCursor != null) {
				mCursor.moveToFirst();
			}
			return mCursor;		
	}	
	
	public Cursor fetchNews(String newsgetid) throws SQLException {
		Cursor mCursor =
			mDb.query(true, DATABASE_TABLE, new String[] {newstitle,
					newslargeimage, newsstory}, newsid + "='" + newsgetid + "'", null,
					null, null, null, null);
		if (mCursor != null) {
			mCursor.moveToFirst();
		}
		return mCursor;
	}	
	
}